@@ -1,8 +1,15 @@
 #' Mean and standard error from collection of spectra
 #'
-#' A method to compute the mean of values across members of a collections of
-#' spectra. Computes the mean at each wavelength across all the spectra in the
-#' collection returning a spectral object.
+#' Method to compute the "parallel" mean and the SEM. The spectral
+#' values are summarised across members of a collection of spectra or of a
+#' spectral object containing multiple spectra in long form.
+#'
+#' @details Method specializations compute the  mean and SEM at
+#'   each wavelength across a group of spectra stored in an object of one of the
+#'   classes defined in package 'photobiology'. Omission of NAs is done
+#'   separately at each wavelength. Interpolation is not applied, so all spectra
+#'   in \code{x} must share the same set of wavelengths. An error is triggered
+#'   if this condition is nor fulfilled. The value passed as argument to `mult`
 #'
 #' @param x An R object Currently this package defines methods for collections of
 #'    spectral objects.
@@ -12,24 +19,27 @@
 #' @param ...	Further arguments passed to or from other methods.
 #'
 #' @return If \code{x} is a collection spectral of objects, such as a
-#'   "filter_mspct" object, the returned object is of same class as the
-#'   members of the collection, such as "filter_spct", containing the mean
-#'   spectrum.
+#'   \code{"filter_mspct"} object, the returned object is of same class as the
+#'   members of the collection, such as \code{"filter_spct"}, containing the
+#'   summary spectrum, with variables with names tagged for summaries other
+#'   than mean or median.
 #'
-#' @note Trimming of extreme values and omission of NAs is done separately at
-#'   each wavelength. Interpolation is not applied, so all spectra in \code{x}
-#'   must share the same set of wavelengths.
+#' @note Objects of classes \code{raw_spct} and \code{cps_spct} can contain data
+#'   from multiple scans in multiple variables or "columns". The methods accept
+#'   as arguments objects of these classes only if spectra contain data for a
+#'   single spectrometer scan. In the case of \code{cps_spct} objects, a single
+#'   column can also contain data from multiple scans spliced into a single
+#'   variable.
 #'
-#'   Objects of classes raw_spct and cps_spct can contain data from multiple
-#'   scans. This functions are implemented for these classes only for the case
-#'   when all member spectra contain data for a single scan, or spliced into a
-#'   single column in the case of cps_spct members.
-#'
-#' @seealso See \code{\link[base]{mean}} for the \code{mean()} method used for
-#'   the computations.
+#' @seealso See \code{\link[base]{mean}} for the \code{mean()} method to
+#'   compute the mean and \code{\link{se}} for the method used to compute the
+#'   standard error of the mean.
 #'
 #' @export
 #'
+#' @examples
+#' s_mean_se(sun_evening.mspct)
+#'
 s_mean_se <- function(x, na.rm, mult, ...)
   UseMethod("s_mean_se")
 
@@ -44,6 +54,14 @@ s_mean_se.default <- function(x, na.rm = FALSE, mult = 1, ...) {
   ifelse(is.any_mspct(x), do.call(class(x[[1]])[1], args = list()), NA)
 }
 
+#' @describeIn s_mean_se
+#'
+#' @export
+#'
+s_mean_se.generic_spct <- function(x, na.rm = FALSE, mult = 1, ...) {
+  s_mean_se(subset2mspct(x), na.rm = na.rm, mult = mult, ...)
+}
+
 #' @describeIn s_mean_se
 #'
 #' @export
