@@ -1,37 +1,45 @@
 #' Sum from collection of spectra
 #'
-#' A method to compute the sum of values across members of a collections of
-#' spectra. Computes the sum at each wavelength across all the spectra in the
-#' collection returning a spectral object.
+#' Method to compute the "parallel" sum of values across members of a
+#' collection of spectra or of a spectral object containing multiple spectra in
+#' long form.
 #'
-#' @param x An R object. Currently this package defines methods for collections of
-#'    spectral objects.
-#' @param na.rm	logical. A value indicating whether NA values should be stripped
+#' @details Method specializations compute the sum at each wavelength across a
+#'   group of spectra stored in an object of one of the classes defined in
+#'   package 'photobiology'. Omission of NAs is done
+#'   separately at each wavelength. Interpolation is not applied, so all spectra
+#'   in \code{x} must share the same set of wavelengths. An error is triggered
+#'   if this condition is nor fulfilled.
+#'
+#' @param x An R object.
+#' @param na.rm	logical A value indicating whether NA values should be stripped
 #'   before the computation proceeds.
 #' @param ...	Further arguments passed to or from other methods.
 #'
 #' @return If \code{x} is a collection spectral of objects, such as a
-#'   "filter_mspct" object, the returned object is of same class as the
-#'   members of the collection, such as "filter_spct", containing the sum
-#'   of the spectra.
+#'   \code{"filter_mspct"} object, the returned object is of same class as the
+#'   members of the collection, such as \code{"filter_spct"}, containing the
+#'   summary spectrum, with variables with names tagged for summaries other
+#'   than mean or median.
 #'
-#' @note Omission of NAs is done separately at each wavelength. Interpolation is
-#'   not applied, so all spectra in \code{x} must share the same set of
-#'   wavelengths.
+#' @note Objects of classes \code{raw_spct} and \code{cps_spct} can contain data
+#'   from multiple scans in multiple variables or "columns". The methods accept
+#'   as arguments objects of these classes only if spectra contain data for a
+#'   single spectrometer scan. In the case of \code{cps_spct} objects, a single
+#'   column can also contain data from multiple scans spliced into a single
+#'   variable.
 #'
-#'   A sum of transmitances or reflectances is no longer a well defined physical
-#'   quanttiy, and these sum operations return an object of class generic_spct.
-#'
-#'   Objects of classes raw_spct and cps_spct can contain data from multiple
-#'   scans. This functions are implemented for these classes only for the case
-#'   when all member spectra contain data for a single scan, or spliced into a
-#'   single column in the case of cps_spct members.
+#'   The sum operation is meaningful only for certain physical
+#'   quantities or bases of expression.
 #'
 #' @seealso See \code{\link[base]{sum}} for the \code{sum()} method used for
 #'   the computations.
 #'
 #' @export
 #'
+#' @examples
+#' s_sum(sun_evening.mspct)
+#'
 s_sum <- function(x, na.rm, ...)
   UseMethod("s_sum")
 
@@ -46,6 +54,14 @@ s_sum.default <- function(x, na.rm = FALSE, ...) {
   ifelse(is.any_mspct(x), do.call(class(x[[1]])[1], args = list()), NA)
 }
 
+#' @describeIn s_sum
+#'
+#' @export
+#'
+s_sum.generic_spct <- function(x, na.rm = FALSE, ...) {
+  s_sum(subset2mspct(x), na.rm = na.rm, ...)
+}
+
 #' @describeIn s_sum
 #'
 #' @export
